@@ -1,7 +1,9 @@
 from zope.interface import Interface, implements
 from collective.flexitopic.browser.flexitopicview import FlexiTopicView
+from collective.flexitopic.browser.flexitopicview import FlexiCollectionView
 from collective.flexitopic.browser.viewlets import JsViewlet, BaseViewlet
-from collective.geo.kml.interfaces import IKMLOpenLayersViewlet
+from collective.geo.flexitopic.interfaces import IGeoFlexiTopicViewlet
+
 
 class IFlexiTopicMapView(Interface):
     ''' add a map to the flexitopc view'''
@@ -11,6 +13,11 @@ class FlexiTopicMapView(FlexiTopicView):
     implements(IFlexiTopicMapView)
 
 
+class FlexiCollectionMapView(FlexiCollectionView):
+    ''' add a map to the flexitopc view'''
+    implements(IFlexiTopicMapView)
+
+
 class JsMapViewlet(JsViewlet):
     ''' overide the flexitopic js viewlet '''
 
@@ -22,20 +29,23 @@ class JsMapViewlet(JsViewlet):
             qs = qs + field.name + '=' + field.value + "&";
             params[field.name] = field.value;
         });
-        var map = cgmap.config['default-cgmap'].map;
-        var kmls = map.getLayersByClass('OpenLayers.Layer.GML');
-        var kmlUrl = '%s/@@flexitopickml_view' + qs;
-        jQuery("a#flexitopickmlurl").attr('href', kmlUrl);
-        layer = kmls[0];
-        layer.setVisibility(false);
-        layer.loaded = false;
-        layer.setUrl(kmlUrl);
-        layer.refresh({ force: true, params: params });
-        layer.setVisibility(true);
+
+        try {
+            var map = $('#default-cgmap').data('collectivegeo').mapwidget.map;
+        } catch(e) {
+            var map = null;
+        };
+        if ( map != null){
+            var kmls = map.getLayersByClass('OpenLayers.Layer.Vector');
+            var kmlUrl = '%s/@@flexitopickml_view' + qs;
+            jQuery("a#flexitopickmlurl").attr('href', kmlUrl);
+            layer = kmls[0];
+            layer.refresh({url: kmlUrl});
+        };
         '''
 
 class MapViewlet(BaseViewlet):
     '''' render the map based on the query
     '''
-    implements(IKMLOpenLayersViewlet)
+    implements(IGeoFlexiTopicViewlet)
 
