@@ -1,4 +1,5 @@
 import logging
+from Products.CMFCore.utils import getToolByName
 # The profile id of your package:
 PROFILE_ID = 'profile-collective.geo.flexitopic:default'
 
@@ -9,7 +10,13 @@ def do_nothing(context, logger=None):
         logger = logging.getLogger('collective.geo.flexitopic')
         logger.info("Empty upgrade step")
 
-
+def add_ng_collection(context, logger=None):
+    if logger is None:
+        # Called as upgrade step: define our own logger.
+        logger = logging.getLogger('collective.geo.flexitopic')
+    logger.info("Add typeinfo for new style collections")
+    setup = getToolByName(context, 'portal_setup')
+    setup.runImportStepFromProfile(PROFILE_ID, 'typeinfo')
 
 
 def import_various(context):
